import "./tasks/muse.wdl" as muse
import "./tasks/annovar.wdl" as annovar
import "./tasks/vcf2maf.wdl" as vcf2maf


workflow {{ project_name }} {
    
    String sample_id
    File normal_recaled_bam
    File tumor_recaled_bam
    File normal_recaled_bam_index
    File tumor_recaled_bam_index

    String muse_docker
    String annovar_docker
    String maftools_docker
    
    File ref_dir
    String fasta
    File dbmills_dir
    String db_mills
    File dbsnp_dir
    String dbsnp
    File regions
    String disk_size
    String cluster_config
    
    File database

    call muse.muse as muse {
        input:
        ref_dir=ref_dir,
        fasta=fasta,
        dbsnp_dir=dbsnp_dir,
        dbsnp=dbsnp,
        normal_bam=normal_recaled_bam,
        tumor_bam=tumor_recaled_bam,
        normal_bam_index=normal_recaled_bam_index,
        tumor_bam_index=tumor_recaled_bam_index,
        sample=sample_id,
        muse_docker=muse_docker,	
        disk_size=disk_size,
        cluster_config=cluster_config
    }

    call annovar.annovar as annovar {
        input:
        docker=annovar_docker,
        database=database,
        muse_vcf=muse.muse_vcf,
        sample=sample_id,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as vcf2maf {
        input:
        docker=maftools_docker,
        multianno_muse_txt=annovar.multianno_muse_txt,
        sample=sample_id,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
}